# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_analytic_model.models
from visier_api_analytic_model.models.perspective_node_dto import PerspectiveNodeDTO

class TestPerspectiveNodeDTO(unittest.TestCase):
    """PerspectiveNodeDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PerspectiveNodeDTO:
        """Test PerspectiveNodeDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return PerspectiveNodeDTO(
                analytic_object_filters = [
                    visier_api_analytic_model.models.analytic_object_filter_dto.AnalyticObjectFilterDTO(
                        analytic_object_uuid = '', 
                        dimensions = [
                            visier_api_analytic_model.models.dimension_filter_dto.DimensionFilterDTO(
                                dimension_id = '', 
                                dimension_members = [
                                    visier_api_analytic_model.models.dimension_member_dto.DimensionMemberDTO(
                                        dimension_member = [
                                            ''
                                            ], )
                                    ], 
                                symbol_name = '', )
                            ], 
                        symbol_name = '', )
                    ],
                selection_concept_uuid = '',
                symbol_name = ''
            )
        else:
            return PerspectiveNodeDTO(
        )

    def testPerspectiveNodeDTO(self):
        """Test PerspectiveNodeDTO"""
        def validate_instance(instance):
            PerspectiveNodeDTO.model_validate(inst_req_only)
            instance_deserialized = PerspectiveNodeDTO.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class NumericParameterDefinitionDTO(BaseModel):
    """
    The definition of a numeric parameter. These elements are returned as part of the query definition for metric parameter values.
    """ # noqa: E501
    default: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The default value if the end user does not select a member at run time.")
    description: Optional[StrictStr] = Field(default=None, description="The localized description of the numeric parameter.")
    display_name: Optional[StrictStr] = Field(default=None, description="The localized display name of the numeric parameter.", alias="displayName")
    id: Optional[StrictStr] = Field(default=None, description="The unique ID of the numeric parameter.")
    lower_bound: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The lowest value for the numeric parameter.", alias="lowerBound")
    upper_bound: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The highest value for the numeric parameter.", alias="upperBound")
    __properties: ClassVar[List[str]] = ["default", "description", "displayName", "id", "lowerBound", "upperBound"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NumericParameterDefinitionDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NumericParameterDefinitionDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "default": obj.get("default"),
            "description": obj.get("description"),
            "displayName": obj.get("displayName"),
            "id": obj.get("id"),
            "lowerBound": obj.get("lowerBound"),
            "upperBound": obj.get("upperBound")
        })
        return _obj


